======================
Django Shared Property
======================


.. image:: https://img.shields.io/pypi/v/django_shared_property.svg
        :target: https://pypi.python.org/pypi/django_shared_property

.. image:: https://img.shields.io/travis/schinckel/django-shared-property.svg
        :target: https://travis-ci.org/schinckel/django-shared-property

.. image:: https://ci.appveyor.com/api/projects/status/schinckel/branch/main?svg=true
    :target: https://ci.appveyor.com/project/schinckel/django-shared-property/branch/main
    :alt: Build status on Appveyor

.. image:: https://readthedocs.org/projects/django-shared-property/badge/?version=latest
        :target: https://django-shared-property.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status




Properties that are both ORM expressions and python code.


* Free software: MIT license

* Documentation: https://django-shared-property.readthedocs.io.



Installation:
-------------

.. code-block:: console

    $ pip install django_shared_property

Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `wboxx1/cookiecutter-pypackage-poetry`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`wboxx1/cookiecutter-pypackage-poetry`: https://github.com/wboxx1/cookiecutter-pypackage-poetry
